cofe package
============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   cofe.extern
   cofe.space
   cofe.wrangling

Submodules
----------

cofe.expansion module
---------------------

.. automodule:: cofe.expansion
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: cofe
   :members:
   :undoc-members:
   :show-inheritance:
